# Introduction

beta release at https://pypi.org/project/torch-sentiment/, install with:  
```pip install torch-sentiment```

This repo contains Neural Nets written in the pytorch framework for sentiment analysis.  
A LSTM based torch model can be found in the rnn folder. 

## Install dev
```
conda create -n {env}  
conda install pip  
pip install -e .  
```

## Example
To setup environments and run the rnn example see instructions below:  

```
get the yelp dataset from https://www.yelp.com/dataset
run
```

